@@ -54,12 +54,19 @@ def test_sync_reader(service_name, operator, async_operator):
         assert read_content == content
 
     with operator.open(filename, "rb") as reader:
-        read_content = reader.read(size + 1)
+        read_content = bytearray()
+        while True:
+            chunk = reader.read(size + 1)
+            if not chunk:
+                break
+            read_content.extend(chunk)
+
+        read_content = bytes(read_content)
         assert read_content is not None
         assert read_content == content
 
     buf = bytearray(1)
-    with operator.open(filename, 'rb') as reader:
+    with operator.open(filename, "rb") as reader:
         reader.readinto(buf)
         assert buf == content[:1]
 
